# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalapb.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import descriptor_pb2 as descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='scalapb.proto',
  package='scalapb',
  syntax='proto2',
  serialized_options=b'\n\017scalapb.options\342?\023\n\017scalapb.options\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rscalapb.proto\x12\x07scalapb\x1a\x10\x64\x65scriptor.proto\"\xda\x08\n\x0eScalaPbOptions\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66lat_package\x18\x02 \x01(\x08\x12\x0e\n\x06import\x18\x03 \x03(\t\x12\x10\n\x08preamble\x18\x04 \x03(\t\x12\x13\n\x0bsingle_file\x18\x05 \x01(\x08\x12\x1d\n\x15no_primitive_wrappers\x18\x07 \x01(\x08\x12\x1a\n\x12primitive_wrappers\x18\x06 \x01(\x08\x12\x17\n\x0f\x63ollection_type\x18\x08 \x01(\t\x12%\n\x17preserve_unknown_fields\x18\t \x01(\x08:\x04true\x12\x13\n\x0bobject_name\x18\n \x01(\t\x12\x33\n\x05scope\x18\x0b \x01(\x0e\x32$.scalapb.ScalaPbOptions.OptionsScope\x12\x14\n\x06lenses\x18\x0c \x01(\x08:\x04true\x12\x1f\n\x17retain_source_code_info\x18\r \x01(\x08\x12\x10\n\x08map_type\x18\x0e \x01(\t\x12(\n no_default_values_in_constructor\x18\x0f \x01(\x08\x12\x42\n\x11\x65num_value_naming\x18\x10 \x01(\x0e\x32\'.scalapb.ScalaPbOptions.EnumValueNaming\x12 \n\x11\x65num_strip_prefix\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\x46\n\x13\x61ux_message_options\x18\x12 \x03(\x0b\x32).scalapb.ScalaPbOptions.AuxMessageOptions\x12\x42\n\x11\x61ux_field_options\x18\x13 \x03(\x0b\x32\'.scalapb.ScalaPbOptions.AuxFieldOptions\x12@\n\x10\x61ux_enum_options\x18\x14 \x03(\x0b\x32&.scalapb.ScalaPbOptions.AuxEnumOptions\x12\x12\n\nbytes_type\x18\x15 \x01(\t\x12\'\n\x1dtest_only_no_java_conversions\x18\xa1\x8d\x06 \x01(\x08\x1aM\n\x11\x41uxMessageOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12(\n\x07options\x18\x02 \x01(\x0b\x32\x17.scalapb.MessageOptions\x1aI\n\x0f\x41uxFieldOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12&\n\x07options\x18\x02 \x01(\x0b\x32\x15.scalapb.FieldOptions\x1aG\n\x0e\x41uxEnumOptions\x12\x0e\n\x06target\x18\x01 \x01(\t\x12%\n\x07options\x18\x02 \x01(\x0b\x32\x14.scalapb.EnumOptions\"%\n\x0cOptionsScope\x12\x08\n\x04\x46ILE\x10\x00\x12\x0b\n\x07PACKAGE\x10\x01\"2\n\x0f\x45numValueNaming\x12\x0f\n\x0b\x41S_IN_PROTO\x10\x00\x12\x0e\n\nCAMEL_CASE\x10\x01\"\xac\x01\n\x0eMessageOptions\x12\x0f\n\x07\x65xtends\x18\x01 \x03(\t\x12\x19\n\x11\x63ompanion_extends\x18\x02 \x03(\t\x12\x13\n\x0b\x61nnotations\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x1d\n\x15\x63ompanion_annotations\x18\x05 \x03(\t\x12\x1c\n\x14sealed_oneof_extends\x18\x06 \x03(\t\x12\x0e\n\x06no_box\x18\x07 \x01(\x08\"\xa6\x01\n\x0c\x46ieldOptions\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x12\n\nscala_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_type\x18\x03 \x01(\t\x12\x10\n\x08key_type\x18\x04 \x01(\t\x12\x12\n\nvalue_type\x18\x05 \x01(\t\x12\x13\n\x0b\x61nnotations\x18\x06 \x03(\t\x12\x10\n\x08map_type\x18\x07 \x01(\t\x12\x0e\n\x06no_box\x18\x1e \x01(\x08\"G\n\x0b\x45numOptions\x12\x0f\n\x07\x65xtends\x18\x01 \x03(\t\x12\x19\n\x11\x63ompanion_extends\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"7\n\x10\x45numValueOptions\x12\x0f\n\x07\x65xtends\x18\x01 \x03(\t\x12\x12\n\nscala_name\x18\x02 \x01(\t\"\x1f\n\x0cOneofOptions\x12\x0f\n\x07\x65xtends\x18\x01 \x03(\t:G\n\x07options\x12\x1c.google.protobuf.FileOptions\x18\xfc\x07 \x01(\x0b\x32\x17.scalapb.ScalaPbOptions:J\n\x07message\x12\x1f.google.protobuf.MessageOptions\x18\xfc\x07 \x01(\x0b\x32\x17.scalapb.MessageOptions:D\n\x05\x66ield\x12\x1d.google.protobuf.FieldOptions\x18\xfc\x07 \x01(\x0b\x32\x15.scalapb.FieldOptions:I\n\x0c\x65num_options\x12\x1c.google.protobuf.EnumOptions\x18\xfc\x07 \x01(\x0b\x32\x14.scalapb.EnumOptions:Q\n\nenum_value\x12!.google.protobuf.EnumValueOptions\x18\xfc\x07 \x01(\x0b\x32\x19.scalapb.EnumValueOptions:D\n\x05oneof\x12\x1d.google.protobuf.OneofOptions\x18\xfc\x07 \x01(\x0b\x32\x15.scalapb.OneofOptionsB\'\n\x0fscalapb.options\xe2?\x13\n\x0fscalapb.options\x10\x01'
  ,
  dependencies=[descriptor__pb2.DESCRIPTOR,])


OPTIONS_FIELD_NUMBER = 1020
options = _descriptor.FieldDescriptor(
  name='options', full_name='scalapb.options', index=0,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MESSAGE_FIELD_NUMBER = 1020
message = _descriptor.FieldDescriptor(
  name='message', full_name='scalapb.message', index=1,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
FIELD_FIELD_NUMBER = 1020
field = _descriptor.FieldDescriptor(
  name='field', full_name='scalapb.field', index=2,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_OPTIONS_FIELD_NUMBER = 1020
enum_options = _descriptor.FieldDescriptor(
  name='enum_options', full_name='scalapb.enum_options', index=3,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_VALUE_FIELD_NUMBER = 1020
enum_value = _descriptor.FieldDescriptor(
  name='enum_value', full_name='scalapb.enum_value', index=4,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_FIELD_NUMBER = 1020
oneof = _descriptor.FieldDescriptor(
  name='oneof', full_name='scalapb.oneof', index=5,
  number=1020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

_SCALAPBOPTIONS_OPTIONSSCOPE = _descriptor.EnumDescriptor(
  name='OptionsScope',
  full_name='scalapb.ScalaPbOptions.OptionsScope',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACKAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1070,
  serialized_end=1107,
)
_sym_db.RegisterEnumDescriptor(_SCALAPBOPTIONS_OPTIONSSCOPE)

_SCALAPBOPTIONS_ENUMVALUENAMING = _descriptor.EnumDescriptor(
  name='EnumValueNaming',
  full_name='scalapb.ScalaPbOptions.EnumValueNaming',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AS_IN_PROTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMEL_CASE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1109,
  serialized_end=1159,
)
_sym_db.RegisterEnumDescriptor(_SCALAPBOPTIONS_ENUMVALUENAMING)


_SCALAPBOPTIONS_AUXMESSAGEOPTIONS = _descriptor.Descriptor(
  name='AuxMessageOptions',
  full_name='scalapb.ScalaPbOptions.AuxMessageOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='scalapb.ScalaPbOptions.AuxMessageOptions.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='scalapb.ScalaPbOptions.AuxMessageOptions.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=920,
)

_SCALAPBOPTIONS_AUXFIELDOPTIONS = _descriptor.Descriptor(
  name='AuxFieldOptions',
  full_name='scalapb.ScalaPbOptions.AuxFieldOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='scalapb.ScalaPbOptions.AuxFieldOptions.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='scalapb.ScalaPbOptions.AuxFieldOptions.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=995,
)

_SCALAPBOPTIONS_AUXENUMOPTIONS = _descriptor.Descriptor(
  name='AuxEnumOptions',
  full_name='scalapb.ScalaPbOptions.AuxEnumOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='scalapb.ScalaPbOptions.AuxEnumOptions.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='scalapb.ScalaPbOptions.AuxEnumOptions.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=997,
  serialized_end=1068,
)

_SCALAPBOPTIONS = _descriptor.Descriptor(
  name='ScalaPbOptions',
  full_name='scalapb.ScalaPbOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_name', full_name='scalapb.ScalaPbOptions.package_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flat_package', full_name='scalapb.ScalaPbOptions.flat_package', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='import', full_name='scalapb.ScalaPbOptions.import', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preamble', full_name='scalapb.ScalaPbOptions.preamble', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_file', full_name='scalapb.ScalaPbOptions.single_file', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_primitive_wrappers', full_name='scalapb.ScalaPbOptions.no_primitive_wrappers', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primitive_wrappers', full_name='scalapb.ScalaPbOptions.primitive_wrappers', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_type', full_name='scalapb.ScalaPbOptions.collection_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_unknown_fields', full_name='scalapb.ScalaPbOptions.preserve_unknown_fields', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_name', full_name='scalapb.ScalaPbOptions.object_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='scalapb.ScalaPbOptions.scope', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lenses', full_name='scalapb.ScalaPbOptions.lenses', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retain_source_code_info', full_name='scalapb.ScalaPbOptions.retain_source_code_info', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_type', full_name='scalapb.ScalaPbOptions.map_type', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_default_values_in_constructor', full_name='scalapb.ScalaPbOptions.no_default_values_in_constructor', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum_value_naming', full_name='scalapb.ScalaPbOptions.enum_value_naming', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum_strip_prefix', full_name='scalapb.ScalaPbOptions.enum_strip_prefix', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aux_message_options', full_name='scalapb.ScalaPbOptions.aux_message_options', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aux_field_options', full_name='scalapb.ScalaPbOptions.aux_field_options', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aux_enum_options', full_name='scalapb.ScalaPbOptions.aux_enum_options', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_type', full_name='scalapb.ScalaPbOptions.bytes_type', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_only_no_java_conversions', full_name='scalapb.ScalaPbOptions.test_only_no_java_conversions', index=21,
      number=100001, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALAPBOPTIONS_AUXMESSAGEOPTIONS, _SCALAPBOPTIONS_AUXFIELDOPTIONS, _SCALAPBOPTIONS_AUXENUMOPTIONS, ],
  enum_types=[
    _SCALAPBOPTIONS_OPTIONSSCOPE,
    _SCALAPBOPTIONS_ENUMVALUENAMING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=1159,
)


_MESSAGEOPTIONS = _descriptor.Descriptor(
  name='MessageOptions',
  full_name='scalapb.MessageOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extends', full_name='scalapb.MessageOptions.extends', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companion_extends', full_name='scalapb.MessageOptions.companion_extends', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='scalapb.MessageOptions.annotations', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='scalapb.MessageOptions.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companion_annotations', full_name='scalapb.MessageOptions.companion_annotations', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sealed_oneof_extends', full_name='scalapb.MessageOptions.sealed_oneof_extends', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_box', full_name='scalapb.MessageOptions.no_box', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1334,
)


_FIELDOPTIONS = _descriptor.Descriptor(
  name='FieldOptions',
  full_name='scalapb.FieldOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='scalapb.FieldOptions.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scala_name', full_name='scalapb.FieldOptions.scala_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_type', full_name='scalapb.FieldOptions.collection_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_type', full_name='scalapb.FieldOptions.key_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='scalapb.FieldOptions.value_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='scalapb.FieldOptions.annotations', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_type', full_name='scalapb.FieldOptions.map_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_box', full_name='scalapb.FieldOptions.no_box', index=7,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1503,
)


_ENUMOPTIONS = _descriptor.Descriptor(
  name='EnumOptions',
  full_name='scalapb.EnumOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extends', full_name='scalapb.EnumOptions.extends', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companion_extends', full_name='scalapb.EnumOptions.companion_extends', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='scalapb.EnumOptions.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1576,
)


_ENUMVALUEOPTIONS = _descriptor.Descriptor(
  name='EnumValueOptions',
  full_name='scalapb.EnumValueOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extends', full_name='scalapb.EnumValueOptions.extends', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scala_name', full_name='scalapb.EnumValueOptions.scala_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1633,
)


_ONEOFOPTIONS = _descriptor.Descriptor(
  name='OneofOptions',
  full_name='scalapb.OneofOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extends', full_name='scalapb.OneofOptions.extends', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1666,
)

_SCALAPBOPTIONS_AUXMESSAGEOPTIONS.fields_by_name['options'].message_type = _MESSAGEOPTIONS
_SCALAPBOPTIONS_AUXMESSAGEOPTIONS.containing_type = _SCALAPBOPTIONS
_SCALAPBOPTIONS_AUXFIELDOPTIONS.fields_by_name['options'].message_type = _FIELDOPTIONS
_SCALAPBOPTIONS_AUXFIELDOPTIONS.containing_type = _SCALAPBOPTIONS
_SCALAPBOPTIONS_AUXENUMOPTIONS.fields_by_name['options'].message_type = _ENUMOPTIONS
_SCALAPBOPTIONS_AUXENUMOPTIONS.containing_type = _SCALAPBOPTIONS
_SCALAPBOPTIONS.fields_by_name['scope'].enum_type = _SCALAPBOPTIONS_OPTIONSSCOPE
_SCALAPBOPTIONS.fields_by_name['enum_value_naming'].enum_type = _SCALAPBOPTIONS_ENUMVALUENAMING
_SCALAPBOPTIONS.fields_by_name['aux_message_options'].message_type = _SCALAPBOPTIONS_AUXMESSAGEOPTIONS
_SCALAPBOPTIONS.fields_by_name['aux_field_options'].message_type = _SCALAPBOPTIONS_AUXFIELDOPTIONS
_SCALAPBOPTIONS.fields_by_name['aux_enum_options'].message_type = _SCALAPBOPTIONS_AUXENUMOPTIONS
_SCALAPBOPTIONS_OPTIONSSCOPE.containing_type = _SCALAPBOPTIONS
_SCALAPBOPTIONS_ENUMVALUENAMING.containing_type = _SCALAPBOPTIONS
DESCRIPTOR.message_types_by_name['ScalaPbOptions'] = _SCALAPBOPTIONS
DESCRIPTOR.message_types_by_name['MessageOptions'] = _MESSAGEOPTIONS
DESCRIPTOR.message_types_by_name['FieldOptions'] = _FIELDOPTIONS
DESCRIPTOR.message_types_by_name['EnumOptions'] = _ENUMOPTIONS
DESCRIPTOR.message_types_by_name['EnumValueOptions'] = _ENUMVALUEOPTIONS
DESCRIPTOR.message_types_by_name['OneofOptions'] = _ONEOFOPTIONS
DESCRIPTOR.extensions_by_name['options'] = options
DESCRIPTOR.extensions_by_name['message'] = message
DESCRIPTOR.extensions_by_name['field'] = field
DESCRIPTOR.extensions_by_name['enum_options'] = enum_options
DESCRIPTOR.extensions_by_name['enum_value'] = enum_value
DESCRIPTOR.extensions_by_name['oneof'] = oneof
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScalaPbOptions = _reflection.GeneratedProtocolMessageType('ScalaPbOptions', (_message.Message,), {

  'AuxMessageOptions' : _reflection.GeneratedProtocolMessageType('AuxMessageOptions', (_message.Message,), {
    'DESCRIPTOR' : _SCALAPBOPTIONS_AUXMESSAGEOPTIONS,
    '__module__' : 'scalapb_pb2'
    # @@protoc_insertion_point(class_scope:scalapb.ScalaPbOptions.AuxMessageOptions)
    })
  ,

  'AuxFieldOptions' : _reflection.GeneratedProtocolMessageType('AuxFieldOptions', (_message.Message,), {
    'DESCRIPTOR' : _SCALAPBOPTIONS_AUXFIELDOPTIONS,
    '__module__' : 'scalapb_pb2'
    # @@protoc_insertion_point(class_scope:scalapb.ScalaPbOptions.AuxFieldOptions)
    })
  ,

  'AuxEnumOptions' : _reflection.GeneratedProtocolMessageType('AuxEnumOptions', (_message.Message,), {
    'DESCRIPTOR' : _SCALAPBOPTIONS_AUXENUMOPTIONS,
    '__module__' : 'scalapb_pb2'
    # @@protoc_insertion_point(class_scope:scalapb.ScalaPbOptions.AuxEnumOptions)
    })
  ,
  'DESCRIPTOR' : _SCALAPBOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.ScalaPbOptions)
  })
_sym_db.RegisterMessage(ScalaPbOptions)
_sym_db.RegisterMessage(ScalaPbOptions.AuxMessageOptions)
_sym_db.RegisterMessage(ScalaPbOptions.AuxFieldOptions)
_sym_db.RegisterMessage(ScalaPbOptions.AuxEnumOptions)

MessageOptions = _reflection.GeneratedProtocolMessageType('MessageOptions', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.MessageOptions)
  })
_sym_db.RegisterMessage(MessageOptions)

FieldOptions = _reflection.GeneratedProtocolMessageType('FieldOptions', (_message.Message,), {
  'DESCRIPTOR' : _FIELDOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.FieldOptions)
  })
_sym_db.RegisterMessage(FieldOptions)

EnumOptions = _reflection.GeneratedProtocolMessageType('EnumOptions', (_message.Message,), {
  'DESCRIPTOR' : _ENUMOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.EnumOptions)
  })
_sym_db.RegisterMessage(EnumOptions)

EnumValueOptions = _reflection.GeneratedProtocolMessageType('EnumValueOptions', (_message.Message,), {
  'DESCRIPTOR' : _ENUMVALUEOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.EnumValueOptions)
  })
_sym_db.RegisterMessage(EnumValueOptions)

OneofOptions = _reflection.GeneratedProtocolMessageType('OneofOptions', (_message.Message,), {
  'DESCRIPTOR' : _ONEOFOPTIONS,
  '__module__' : 'scalapb_pb2'
  # @@protoc_insertion_point(class_scope:scalapb.OneofOptions)
  })
_sym_db.RegisterMessage(OneofOptions)

options.message_type = _SCALAPBOPTIONS
descriptor__pb2.FileOptions.RegisterExtension(options)
message.message_type = _MESSAGEOPTIONS
descriptor__pb2.MessageOptions.RegisterExtension(message)
field.message_type = _FIELDOPTIONS
descriptor__pb2.FieldOptions.RegisterExtension(field)
enum_options.message_type = _ENUMOPTIONS
descriptor__pb2.EnumOptions.RegisterExtension(enum_options)
enum_value.message_type = _ENUMVALUEOPTIONS
descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value)
oneof.message_type = _ONEOFOPTIONS
descriptor__pb2.OneofOptions.RegisterExtension(oneof)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import base64
from typing import Dict, List

from casperlabs_client import CasperLabsClient, reformat
from casperlabs_client.decorators import guarded_command


NAME: str = "stream-events"
HELP: str = "Stream block and deploy state transition events."
OPTIONS = [
    [("--all",), dict(action="store_true", help="Subscribe to all events")],
    [("--block-added",), dict(action="store_true", help="Block added")],
    [("--block-finalized",), dict(action="store_true", help="Block finalized")],
    [("--deploy-added",), dict(action="store_true", help="Deploy added")],
    [("--deploy-discarded",), dict(action="store_true", help="Deploy discarded")],
    [("--deploy-requeued",), dict(action="store_true", help="Deploy requeued")],
    [("--deploy-processed",), dict(action="store_true", help="Deploy processed")],
    [("--deploy-finalized",), dict(action="store_true", help="Deploy finalized")],
    [("--deploy-orphaned",), dict(action="store_true", help="Deploy orphaned")],
    [
        ("-k", "--account-hash"),
        dict(
            action="append",
            help="Filter by (possibly multiple) account public key hash(es)",
        ),
    ],
    [
        ("-d", "--deploy-hash"),
        dict(action="append", help="Filter by (possibly multiple) deploy hash(es)"),
    ],
    [
        ("-f", "--format"),
        dict(
            required=False,
            default="text",
            choices=("json", "binary", "text"),
            help="Choose output format. Defaults to text representation.",
        ),
    ],
    [
        ("--min-event-id",),
        dict(
            required=False,
            default=0,
            type=int,
            help=(
                "Supports replaying events from a given ID. If the value is 0, it it will subscribe to future events; "
                "if it's non-zero, it will replay all past events from that ID, without subscribing to new. "
                "To catch up with events from the beginning, start from 1."
            ),
        ),
    ],
    [
        ("--max-event-id",),
        dict(
            required=False,
            default=0,
            type=int,
            help="Supports replaying events to a given ID.",
        ),
    ],
]


def _add_to_list(maybe_value) -> List:
    if maybe_value:
        return [maybe_value]
    else:
        return []


@guarded_command
def method(casperlabs_client: CasperLabsClient, args: Dict):
    kwargs = dict(
        account_public_key_hashes=_add_to_list(args.get("account_hash")),
        deploy_hashes=_add_to_list(args.get("deploy_hash")),
    )
    for key in (
        "all",
        "block_added",
        "block_finalized",
        "deploy_added",
        "deploy_discarded",
        "deploy_requeued",
        "deploy_processed",
        "deploy_finalized",
        "deploy_orphaned",
        "min_event_id",
        "max_event_id",
    ):
        kwargs[key] = args.get(key)
    stream = casperlabs_client.stream_events(**kwargs)

    output_format = args.get("format")
    for event in stream:
        if output_format == "binary":
            print(base64.b64encode(event.SerializeToString()).decode())
        elif output_format == "json":
            print(reformat.jsonify(event))
        else:
            print(reformat.hexify(event))



# -*- coding: utf-8 -*-
from .key_holder import KeyHolder  # noqa:F401
from .ed25519 import ED25519Key  # noqa:F401
from .secp256k1 import SECP256K1Key  # noqa:F401
from .helper_methods import class_from_algorithm, key_holder_object  # noqa:F401



# -*- coding: utf-8 -*-
"""
Command line interface for CasperLabsClient.
"""

import argparse
import sys

from casperlabs_client.io import read_version

from casperlabs_client import CasperLabsClient, consts
from casperlabs_client.commands import (
    account_hash_cmd,
    balance_cmd,
    deploy_cmd,
    keygen_cmd,
    make_deploy_cmd,
    propose_cmd,
    stream_events_cmd,
    transfer_cmd,
    sign_deploy_cmd,
    send_deploy_cmd,
    query_state_cmd,
    show_block_cmd,
    show_deploy_cmd,
    show_blocks_cmd,
    show_deploys_cmd,
    show_peers_cmd,
    validator_keygen_cmd,
    visualize_dag_cmd,
)


def cli(*arguments) -> int:
    """
    Parse list of method line arguments and call appropriate method.
    """

    class Parser:
        def __init__(self):
            # The --help option added by default has a short version -h, which conflicts
            # with short version of --host, so we need to disable it.
            self.parser = argparse.ArgumentParser(
                prog="casperlabs_client", add_help=False
            )
            self.parser.add_argument(
                "--help",
                action="help",
                default=argparse.SUPPRESS,
                help="show this help message and exit",
            )
            self.parser.add_argument(
                "-h",
                "--host",
                required=False,
                default=consts.DEFAULT_HOST,
                type=str,
                help="Hostname or IP of node on which gRPC service is running.",
            )
            self.parser.add_argument(
                "-p",
                "--port",
                required=False,
                default=consts.DEFAULT_PORT,
                type=int,
                help="Port used for external gRPC API.",
            )
            self.parser.add_argument(
                "--port-internal",
                required=False,
                default=consts.DEFAULT_INTERNAL_PORT,
                type=int,
                help="Port used for internal gRPC API.",
            )
            self.parser.add_argument(
                "--node-id",
                required=False,
                type=str,
                help="node_id parameter for TLS connection",
            )
            self.parser.add_argument(
                "--certificate-file",
                required=False,
                type=str,
                help="Certificate file for TLS connection",
            )
            self.parser.add_argument(
                "--version", action="version", version=read_version()
            )
            self.sp = self.parser.add_subparsers(help="Choose a request")

            def no_command(casperlabs_client, args):
                print(
                    "You must provide a method. --help for documentation of commands."
                )
                self.parser.print_usage()
                return 1

            self.parser.set_defaults(function=no_command)

        def add_command(
            self, command_name: str, function, help_message: str, argument_list: list
        ):
            """ Add main command to parser """
            command_parser = self.sp.add_parser(command_name, help=help_message)
            command_parser.set_defaults(function=function)
            for (args, options) in argument_list:
                command_parser.add_argument(*args, **options)

        def run(self, argv):
            # Using dict rather than namespace to allow dual interface with library
            args = vars(self.parser.parse_args(argv))
            return args["function"](
                CasperLabsClient(
                    args.get("host"),
                    args.get("port"),
                    args.get("port_internal"),
                    args.get("node_id"),
                    args.get("certificate_file"),
                ),
                args,
            )

    parser = Parser()

    for command in (
        account_hash_cmd,
        balance_cmd,
        deploy_cmd,
        keygen_cmd,
        make_deploy_cmd,
        propose_cmd,
        query_state_cmd,
        send_deploy_cmd,
        show_block_cmd,
        show_blocks_cmd,
        show_deploy_cmd,
        show_deploys_cmd,
        show_peers_cmd,
        sign_deploy_cmd,
        stream_events_cmd,
        transfer_cmd,
        validator_keygen_cmd,
        visualize_dag_cmd,
    ):
        parser.add_command(command.NAME, command.method, command.HELP, command.OPTIONS)

    return parser.run([str(a) for a in arguments])


def main():
    return cli(*sys.argv[1:])


if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-
from pathlib import Path
from typing import Dict

from casperlabs_client import CasperLabsClient
from casperlabs_client.commands.common_options import DIRECTORY_FOR_WRITE_OPTION
from casperlabs_client.decorators import guarded_command

NAME: str = "validator-keygen"
HELP: str = """Generate validator and node keys.

Usage: casperlabs-client keygen <existing output directory>
Command will override existing files!
Generated files:
   node-id               # node ID as in casperlabs://c0a6c82062461c9b7f9f5c3120f44589393edf31@<NODE ADDRESS>?protocol=40400&discovery=40404
                         # derived from node.key.pem
   node.certificate.pem  # TLS certificate used for node-to-node interaction encryption
                         # derived from node.key.pem
   node.key.pem          # secp256r1 private key
   validator-id          # validator ID in Base64 format; can be used in accounts.csv
                         # derived from validator.public.pem
   validator-id-hex      # validator ID in hex, derived from validator.public.pem
   validator-private.pem # ed25519 private key
   validator-public.pem  # ed25519 public key"""
OPTIONS = (DIRECTORY_FOR_WRITE_OPTION,)


@guarded_command
def method(casperlabs_client: CasperLabsClient, args: Dict):
    directory = Path(args.get("directory")).resolve()
    casperlabs_client.validator_keygen(directory)
    print(f"Keys successfully created in directory: {str(directory.absolute())}")



# -*- coding: utf-8 -*-
import argparse
from typing import Dict

from casperlabs_client import CasperLabsClient
from casperlabs_client.arg_types import positive_integer
from casperlabs_client.decorators import guarded_command


NAME: str = "vdag"
HELP: str = "DAG in DOT format. You need to install Graphviz from https://www.graphviz.org/ to use it."
DOT_FORMATS = (
    "canon,cmap,cmapx,cmapx_np,dot,dot_json,eps,fig,gd,gd2,gif,gv,imap,imap_np,ismap,jpe,jpeg,jpg,json,"
    "json0,mp,pdf,pic,plain,plain-ext,png,pov,ps,ps2,svg,svgz,tk,vml,vmlz,vrml,wbmp,x11,xdot,xdot1.2,"
    "xdot1.4,xdot_json,xlib"
)


def dot_output(file_name):
    """
    Check file name has an extension of one of file formats supported by Graphviz.
    """
    parts = file_name.split(".")
    if len(parts) == 1:
        raise argparse.ArgumentTypeError(
            f"'{file_name}' has no extension indicating file format"
        )
    else:
        file_format = parts[-1]
        if file_format not in DOT_FORMATS.split(","):
            raise argparse.ArgumentTypeError(
                f"File extension {file_format} not recognized, must be one of {DOT_FORMATS}"
            )
    return file_name


STREAM_CHOICES = ("single-output", "multiple-outputs")


OPTIONS = [
    [
        ("-d", "--depth"),
        dict(
            required=True, type=positive_integer, help="depth in terms of block height"
        ),
    ],
    [
        ("-o", "--out"),
        dict(
            required=False,
            type=dot_output,
            help=f"output image filename, outputs to stdout if not specified, must end with one of {DOT_FORMATS}",
        ),
    ],
    [
        ("-s", "--show-justification-lines"),
        dict(action="store_true", help="if justification lines should be shown"),
    ],
    [
        ("--stream",),
        dict(
            required=False,
            choices=STREAM_CHOICES,
            help=(
                "subscribe to changes, '--out' has to be specified, valid values are "
                f"{STREAM_CHOICES}"
            ),
        ),
    ],
]


@guarded_command
def method(casperlabs_client: CasperLabsClient, args: Dict):
    for o in casperlabs_client.visualize_dag(
        args.get("depth"),
        args.get("out"),
        args.get("show_justification_lines"),
        args.get("stream"),
    ):
        if not args.get("out"):
            print(o)
            break



# -*- coding: utf-8 -*-
import base64
from typing import Union, Optional

import google.protobuf.json_format
import google.protobuf.text_format


def encode_base64(a: bytes):
    return str(base64.b64encode(a), "utf-8")


def hexify(o):
    """
    Convert protobuf message to text format with cryptographic keys and signatures in base 16.
    """
    return google.protobuf.text_format.MessageToString(o)


def jsonify(o):
    return google.protobuf.json_format.MessageToJson(o)


def optional_base64_base16_to_bytes(
    value: Union[str, bytes], field_name: str, expected_length: int = 32
) -> Optional[bytes]:
    """ Takes bytes or str """
    if value is None:
        return

    if isinstance(value, bytes):
        if len(value) != expected_length:
            raise ValueError(
                f"{field_name} in bytes has len: {len(value)}, expected len: {expected_length}"
            )
        return value

    value_bytes = base64.b64decode(value)
    if len(value_bytes) != expected_length:
        value_bytes = bytes.fromhex(value)
        if len(value_bytes) != 32:
            raise ValueError(
                f"{field_name} in bytes has len: {len(value)}, expected len: {expected_length}"
            )
    return value_bytes



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import sys
import re
import errno
import urllib.request
import shutil
from glob import glob
from pathlib import Path
from shutil import copyfile
from typing import Union

from setuptools import setup, find_packages
from os import path
from os.path import basename, dirname, join

from setuptools.command.develop import develop as DevelopCommand
from setuptools.command.install import install as InstallCommand
from distutils.spawn import find_executable

THIS_DIRECTORY = Path(os.path.dirname(os.path.realpath(__file__)))

# Directory with Scala client's bundled contracts

CASPERLABS_DIR = THIS_DIRECTORY.parent / "CasperLabs"
PROTOBUF_DIR = THIS_DIRECTORY / "protobuf"
PROTO_DIR = THIS_DIRECTORY / "casperlabs_client" / "proto"
PACKAGE_DIR = THIS_DIRECTORY / "casperlabs_client"
VERSION_FILE = PACKAGE_DIR / "VERSION"
NAME = "casperlabs_client"


def read_version() -> str:
    with open(VERSION_FILE, "r") as f:
        return f.read().strip()


def proto_compiler_check():
    proto_c = find_executable("protoc")
    if proto_c is None:
        sys.stderr.write(
            "protoc is not installed. "
            "Please install Protocol Buffers binary package for your Operating System.\n"
        )
        sys.exit(-1)


def python_compiler_check():
    if sys.version < "3.7":
        sys.stderr.write(f"{NAME} is only supported on Python versions 3.7+.\n")
        sys.exit(-1)


def make_dirs(dir_path: Union[Path, str]):
    try:
        os.makedirs(dir_path)
    except OSError as e:
        if e.errno != errno.EEXIST:
            raise


def download(url, directory):
    make_dirs(directory)
    urllib.request.urlretrieve(url, join(directory, basename(url)))


def replace_in_place(pairs, file_name):
    import in_place

    with in_place.InPlace(file_name) as f:
        for line in f:
            for r, s in pairs:
                line = re.sub(r, s, line)
            f.write(line)


def modify_files(description, pairs, files):
    print(description)
    for file_name in files:
        print(f"   {file_name}")
        replace_in_place(pairs, file_name)


def run_protoc(file_names, proto_dir=PROTO_DIR):
    import grpc_tools
    from grpc_tools import protoc

    print("Run protoc...")
    google_proto = join(dirname(grpc_tools.__file__), "_proto")
    for file_name in file_names:
        print(f"   {file_name}")
        protoc.main(
            (
                "",
                f"-I{proto_dir}",
                "-I" + google_proto,
                f"--python_out={PACKAGE_DIR}",
                f"--python_grpc_out={PACKAGE_DIR}",
                f"--grpc_python_out={PACKAGE_DIR}",
                file_name,
            )
        )
    clean_up_source_files()


def collect_proto_files():
    print("Collect files...")

    for file_name in Path(PROTOBUF_DIR).glob("**/*.proto"):
        copyfile(file_name, PROTO_DIR / basename(file_name))

    print("Finished collecting files...")


def clean_up_source_files():
    try:
        shutil.rmtree(PROTO_DIR)
    except FileNotFoundError:
        pass


def clean_up_generated_files():
    for file_name in glob(f"{PACKAGE_DIR}/*pb2*py"):
        os.remove(file_name)
    for file_name in glob(f"{PACKAGE_DIR}/*grpc.py"):
        os.remove(file_name)


def run_codegen():
    python_compiler_check()
    proto_compiler_check()
    clean_up_source_files()
    clean_up_generated_files()
    make_dirs(f"{PROTO_DIR}")
    collect_proto_files()
    modify_files(
        "Patch proto files' imports", [(r'".+/', '"')], glob(f"{PROTO_DIR}/*.proto")
    )
    run_protoc(glob(f"{PROTO_DIR}/*.proto"))
    modify_files(
        "Patch generated Python gRPC modules",
        [(r"(import .*_pb2)", r"from . \1")],
        glob(f"{PACKAGE_DIR}/*pb2*py"),
    )
    # modify_files(
    #     "Patch generated Python gRPC modules (for asyncio)",
    #     [(r"(import .*_pb2)", r"from . \1")],
    #     [fn for fn in glob(f"{PACKAGE_DIR}/*_grpc[.]py") if "_pb2_" not in fn],
    # )


def prepare_sdist():
    run_codegen()


if len(sys.argv) > 1 and sys.argv[1] == "sdist":
    prepare_sdist()


with open(path.join(THIS_DIRECTORY, "README.md"), encoding="utf-8") as fh:
    long_description = fh.read()


class CInstall(InstallCommand):
    def run(self):
        super().run()


class CDevelop(DevelopCommand):
    def run(self):
        run_codegen()
        super().run()


setup(
    name=NAME,
    version=read_version(),
    packages=find_packages(),
    setup_requires=[
        "protobuf==3.12.2",
        "grpcio-tools>=1.20",
        "in-place==0.4.0",
        "grpcio>=1.20",
    ],
    install_requires=[
        "protobuf==3.12.2",
        "grpcio>=1.20",
        "grpclib==0.3.1",
        "pyblake2==1.1.2",
        "cryptography==2.8",
        "ecdsa==0.15",
        "pycryptodome==3.9.4",
    ],
    cmdclass={"install": CInstall, "develop": CDevelop},
    description="Python Client for interacting with a CasperLabs Node",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # Hardcoding name for missing version file when package is renamed.
    package_data={"casperlabs_client": [str(VERSION_FILE)]},
    keywords="casperlabs blockchain ethereum smart-contracts",
    author="CasperLabs LLC",
    author_email="testing@casperlabs.io",
    license="CasperLabs Open Source License (COSL)",
    zip_safe=False,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
    ],
    url="https://casperlabs.io/",
    project_urls={
        "Source": "https://github.com/CasperLabs/CasperLabs/tree/dev/integration-testing/client/CasperLabsClient",
        "Readme": "https://github.com/CasperLabs/CasperLabs/blob/dev/integration-testing/client/CasperLabsClient/README.md",
    },
    entry_points={
        "console_scripts": ["casperlabs_client = casperlabs_client.cli:main"]
    },
)
